@@ -365,7 +365,10 @@ const char stress_config[] =
 "#define HAVE_FMA\n"
 "#define HAVE_FMAF\n"
 "#define HAVE_FREMOVEXATTR\n"
+"#define HAVE_FSCONFIG\n"
 "#define HAVE_FSETXATTR\n"
+"#define HAVE_FSMOUNT\n"
+"#define HAVE_FSOPEN\n"
 "#define HAVE_FSTAT\n"
 "#define HAVE_FSTATAT\n"
 "#define HAVE_FSUUID2\n"
@@ -621,6 +624,7 @@ const char stress_config[] =
 "#define HAVE_MNT_ID_REQ\n"
 "#define HAVE_MODE_T\n"
 "#define HAVE_MODIFY_LDT\n"
+"#define HAVE_MOVE_MOUNT\n"
 "#define HAVE_MPFR_H\n"
 "#define HAVE_MPROTECT\n"
 "#define HAVE_MQUEUE_H\n"
@@ -651,6 +655,7 @@ const char stress_config[] =
 "#define HAVE_OPENAT2\n"
 "#define HAVE_OPEN_BY_HANDLE_AT\n"
 "#define HAVE_OPEN_MEMSTREAM\n"
+"#define HAVE_OPEN_TREE\n"
 "#define HAVE_PAGE_REGION\n"
 "#define HAVE_PATHCONF\n"
 "#define HAVE_PAUSE\n"
@@ -832,7 +837,15 @@ const char stress_config[] =
 "#define HAVE_STAT\n"
 "#define HAVE_STATFS\n"
 "#define HAVE_STATX\n"
+"#define HAVE_STRFROMD\n"
+"#define HAVE_STRFROMF\n"
+"#define HAVE_STRFROML\n"
 "#define HAVE_STRINGS_H\n"
+"#define HAVE_STRTOD\n"
+"#define HAVE_STRTOF\n"
+"#define HAVE_STRTOLD\n"
+"#define HAVE_STRTOUL\n"
+"#define HAVE_STRTOULL\n"
 "#define HAVE_SWAP\n"
 "#define HAVE_SWAPCONTEXT\n"
 "#define HAVE_SYMLINKAT\n"
@@ -1102,6 +1115,7 @@ const char stress_config[] =
 "/* #define HAVE_RADIXSORT */\n"
 "/* #define HAVE_REMOVEXATTRAT */\n"
 "/* #define HAVE_RFORK */\n"
+"/* #define HAVE_RSEQ_SLICE_YIELD */\n"
 "/* #define HAVE_SETXATTRAT */\n"
 "/* #define HAVE_STIME */\n"
 "/* #define HAVE_SYS_LOADAVG_H */\n"
